@@ -24,23 +24,29 @@ reference or object).
 =cut
 
 
+use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 use Moose::Util::TypeConstraints;
 
 
-subtype 'CacheFileHandle'
-    => as 'GlobRef'
-    => where { defined Scalar::Util::reftype($_)
-               && Scalar::Util::reftype($_) eq 'GLOB'
-               && $_ == \*_ }
-    => optimize_as { defined $_[0]
-                     && defined Scalar::Util::reftype($_[0])
-                     && Scalar::Util::reftype($_[0]) eq 'GLOB'
-                     && $_[0] == \*_ };
+subtype CacheFileHandle => (
+    as 'GlobRef',
+    where {
+        defined Scalar::Util::reftype($_)
+        && Scalar::Util::reftype($_) eq 'GLOB'
+        && $_ == \*_
+    },
+    optimize_as {
+        defined $_[0]
+        && defined Scalar::Util::reftype($_[0])
+        && Scalar::Util::reftype($_[0]) eq 'GLOB'
+        && $_[0] == \*_
+    },
+);
 
 
 1;
